<?php
/**
 * Implement theme metabox.
 *
 * @package Jumla
 */

if (!function_exists('jumla_add_theme_meta_box')) :

    /**
     * Add the Meta Box
     *
     * @since 1.0.0
     */
    function jumla_add_theme_meta_box()
    {

        $apply_metabox_post_types = array('post', 'page');

        foreach ($apply_metabox_post_types as $key => $type) {
            add_meta_box(
                'jumla-theme-settings',
                esc_html__('Single Page/Post Settings', 'jumla'),
                'jumla_render_theme_settings_metabox',
                $type
            );
        }

    }

endif;

add_action('add_meta_boxes', 'jumla_add_theme_meta_box');

add_action( 'admin_enqueue_scripts', 'jumla_backend_scripts');
if ( ! function_exists( 'jumla_backend_scripts' ) ){
    function jumla_backend_scripts( $hook ) {
        wp_enqueue_style( 'wp-color-picker');
        wp_enqueue_script( 'wp-color-picker');
    }
}

if (!function_exists('jumla_render_theme_settings_metabox')) :

    /**
     * Render theme settings meta box.
     *
     * @since 1.0.0
     */
    function jumla_render_theme_settings_metabox($post, $metabox)
    {

        $post_id = $post->ID;
        $jumla_post_meta_value = get_post_meta($post_id);

        // Meta box nonce for verification.
        wp_nonce_field(basename(__FILE__), 'jumla_meta_box_nonce');
        // Fetch Options list.
        $page_layout = get_post_meta($post_id, 'jumla-meta-select-layout', true);
        $page_image_layout = get_post_meta($post_id, 'jumla-meta-image-layout', true);
        $jumla_meta_checkbox = get_post_meta($post_id, 'jumla-meta-checkbox', true);
        ?>

        <div class="jumla-tab-main">

            <div class="jumla-metabox-tab">
                <ul>
                    <li>
                        <a id="twp-tab-general" class="twp-tab-active" href="javascript:void(0)"><?php esc_html_e('Layout Settings', 'jumla'); ?></a>
                    </li>
                </ul>
            </div>

            <div class="jumla-tab-content">
                
                <div id="twp-tab-general-content" class="jumla-content-wrap jumla-tab-content-active">

                    <div class="jumla-meta-panels">

                        <div class="jumla-opt-wrap jumla-checkbox-wrap">

                            <input id="feature-image-checkbox" name="jumla-meta-checkbox" type="checkbox" <?php if ($jumla_meta_checkbox) { ?> checked="checked" <?php } ?> />

                            <label for="feature-image-checkbox"><?php esc_html_e('Check To Dissable Featured Image As Banner Image', 'jumla'); ?></label>
                        </div>

                         <div class="jumla-opt-wrap jumla-opt-wrap-alt">
                            <label><?php esc_html_e('Single Page/Post Layout', 'jumla'); ?></label>
                            <select name="jumla-meta-select-layout" id="jumla-meta-select-layout">
                                <option value="global" <?php selected('global', $page_layout); ?>>
                                    <?php esc_html_e('Global', 'jumla') ?>
                                </option>
                                <option value="right-sidebar" <?php selected('right-sidebar', $page_layout); ?>>
                                    <?php esc_html_e('Content - Primary Sidebar', 'jumla') ?>
                                </option>
                                <option value="left-sidebar" <?php selected('left-sidebar', $page_layout); ?>>
                                    <?php esc_html_e('Primary Sidebar - Content', 'jumla') ?>
                                </option>
                                <option value="no-sidebar" <?php selected('no-sidebar', $page_layout); ?>>
                                    <?php esc_html_e('No Sidebar', 'jumla') ?>
                                </option>
                            </select>
                        </div>

                        <div class="jumla-opt-wrap jumla-opt-wrap-alt">
                            <label><?php esc_html_e('Single Page/Post Image Layout', 'jumla'); ?></label>
                            <select name="jumla-meta-image-layout" id="jumla-meta-image-layout">
                                <option value="global" <?php selected('global', $page_image_layout); ?>>
                                    <?php esc_html_e('Global', 'jumla') ?>
                                </option>
                                <option value="full" <?php selected('full', $page_image_layout); ?>>
                                    <?php esc_html_e('Full', 'jumla') ?>
                                </option>
                                <option value="left" <?php selected('left', $page_image_layout); ?>>
                                    <?php esc_html_e('Left', 'jumla') ?>
                                </option>
                                <option value="right" <?php selected('right', $page_image_layout); ?>>
                                    <?php esc_html_e('Right', 'jumla') ?>
                                </option>
                                <option value="no-image" <?php selected('no-image', $page_image_layout); ?>>
                                    <?php esc_html_e('No Image', 'jumla') ?>
                                </option>
                            </select>
                        </div>


                    </div>
                </div>

            </div>
        </div>

        <?php
    }

endif;


if (!function_exists('jumla_save_theme_settings_meta')) :

    /**
     * Save theme settings meta box value.
     *
     * @since 1.0.0
     *
     * @param int $post_id Post ID.
     * @param WP_Post $post Post object.
     */
    function jumla_save_theme_settings_meta($post_id, $post)
    {

        // Verify nonce.
        if (!isset($_POST['jumla_meta_box_nonce']) || !wp_verify_nonce($_POST['jumla_meta_box_nonce'], basename(__FILE__))) {
            return;
        }

        // Bail if auto save or revision.
        if (defined('DOING_AUTOSAVE') || is_int(wp_is_post_revision($post)) || is_int(wp_is_post_autosave($post))) {
            return;
        }

        // Check the post being saved == the $post_id to prevent triggering this call for other save_post events.
        if (empty($_POST['post_ID']) || $_POST['post_ID'] != $post_id) {
            return;
        }

        // Check permission.
        if ('page' === $_POST['post_type']) {
            if (!current_user_can('edit_page', $post_id)) {
                return;
            }
        } else if (!current_user_can('edit_post', $post_id)) {
            return;
        }

        $jumla_meta_checkbox = isset($_POST['jumla-meta-checkbox']) ? wp_unslash( esc_html($_POST['jumla-meta-checkbox']) ) : '';
        update_post_meta($post_id, 'jumla-meta-checkbox', sanitize_text_field($jumla_meta_checkbox));

        $jumla_meta_select_layout = isset($_POST['jumla-meta-select-layout']) ? wp_unslash( esc_html($_POST['jumla-meta-select-layout']) ) : '';
        if (!empty($jumla_meta_select_layout)) {
            update_post_meta($post_id, 'jumla-meta-select-layout', sanitize_text_field($jumla_meta_select_layout));
        }
        $jumla_meta_image_layout = isset($_POST['jumla-meta-image-layout']) ? wp_unslash( esc_html($_POST['jumla-meta-image-layout']) ) : '';
        if (!empty($jumla_meta_image_layout)) {
            update_post_meta($post_id, 'jumla-meta-image-layout', sanitize_text_field($jumla_meta_image_layout));
        }

    }

endif;

add_action('save_post', 'jumla_save_theme_settings_meta', 10, 3);